#!/bin/sh

# 	Script:        Install Apollia's Perl Modules and Other Perl Modules.sh
#
#
#	Version 1.0
#	by Apollia of Astroblahhh.Com.  http://astroblahhh.com/
#
#	Mostly completed May 15, 2014.
#
#	Polished a bit August 15, 2014.  And Sept. 8, 2014.
#
#
#
#------------------------------------------------------------------------------
#
# Installs my (Apollia's) Perl modules - plus a few not by me - by either
# symlinking to them, or copying them to:
#
#		/root/zzzzz-tmp/Apollias_Perl_Modules
#
# This script assumes the Perl modules are stored on the same disk as 
# this script.
#
#
# Symlinking is useful if you're debugging and don't want to have to
# frequently copy newly-updated modules to /root/zzzzz-tmp/ .
#
# If you're not debugging, then copying is better, so the modules
# will be read from your RAM disk instead of a physical disk.
#
#
# This script can be run just by double-clicking it - in which case 
# it will symlink by default.
#
#
# But, usually, this script will be launched by a Puppy Setup Kit launcher
# script, such as:
#
#	Launch Lupu5284 Setup Kit - Default for Bruno 2.sh
#
# The launcher script should have a config setting (probably a variable
# named "installer_of_apollia_modules_should") which will enable you to
# specify whether to copy or symlink.
#
#------------------------------------------------------------------------------
#
#
#
# Under the GNU General Public License v3.0.
#
# Copyright (C) 2014  Apollia
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
# Contact info:     http://astroblahhh.com/contact-apollia.shtml
#
# ----



############################################################
############################################################
#
#
#	Don't change this:
#
#

parentdirs_of_puppy_setup_kit=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Parentdirs of Puppy Setup Kit.txt")

#echo "parentdirs_of_puppy_setup_kit - $parentdirs_of_puppy_setup_kit";

#exit;
#
#
#	End of some stuff you shouldn't change.
# 
#
############################################################
############################################################



#######################################################################
#
#   Some stuff you can change
#

terminal_window_title="Bash Script: Install Apollia's Perl Modules and Other Perl Modules"

should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying=true
	# true|false



############################################################
############################################################
#
#   Paths and folder names you can probably leave alone:
#
#

full_path_to_tmp_apollia_perl_modules_folder=/root/zzzzz-tmp/Apollias_Perl_Modules
	# This path is used in every Puppy Setup Kit script or 
	# other script that uses the ApolliaLib modules.
	#
	# Changing it isn't recommended since you'd have to change it in every script.


# And we also need to access some deeper folders in there, so...
name_of_grandparentdir_inside_tmp_apollia_perl_modules_folder=lib
name_of_parentdir_inside_tmp_apollia_perl_modules_folder=perl5

# /root/zzzzz-tmp/Apollias_Perl_Modules/lib
full_path_to_tmp_apollia_perl_modules_grandparentdir="$full_path_to_tmp_apollia_perl_modules_folder/$name_of_grandparentdir_inside_tmp_apollia_perl_modules_folder"


# /root/zzzzz-tmp/Apollias_Perl_Modules/lib/perl5
full_path_to_tmp_apollia_perl_modules_parentdir="$full_path_to_tmp_apollia_perl_modules_grandparentdir/$name_of_parentdir_inside_tmp_apollia_perl_modules_folder"


relative_path_to_setup_kit_parentdir_of_apollia_perl_modules="$parentdirs_of_puppy_setup_kit/Woodland/Apollia's Perl Modules and Other Perl Modules/perl5"



working_dir_for_proc_daemon_perl_module="/root/zzzzz-tmp/ApolliaLib tmp workspace/"


#
#   End of Paths and folder names you can probably leave alone
#
#
############################################################
############################################################



#
#
#   End of Some stuff you can change
#
#   Below this point, nothing else in this script needs to be changed.
#
#
####################################################################################################
####################################################################################################
####################################################################################################




##########################################
#
#
# 	Start of function 
#
#
#	Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes()
#
#

Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes()
{	
	local quotes_escaped
	local spaces_escaped
	quotes_escaped=$(echo "$1" | sed -e "s/'/'\"'\"'/g")

	echo "'$quotes_escaped'"
}

#
#
#	End of function
#
#	Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes()
#
#
###########################################################





##########################################################
#
#	Now, we set a bunch of variables related to the script's
#	path and filename.
#


Get_Script_Path_and_Filename()
{
	THIS_SCRIPT_FILE_NAME="$(basename "${BASH_SOURCE[0]}" )"

	THIS_SCRIPT_FOLDER="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

	full_path_to_this_script="$THIS_SCRIPT_FOLDER/$THIS_SCRIPT_FILE_NAME"

	escaped_enclosed_full_path_to_this_script=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$full_path_to_this_script")
}



Get_Script_Path_and_Filename



##########################################################
#
#	Then, we announce this script's name, path, and what it is.
#


Announce_Script_Now_Running()
{
	echo -e "\n\n*(*)*\n\nBash Script Now Running:\n"
	
	echo "	$THIS_SCRIPT_FILE_NAME

Full path:
	$full_path_to_this_script"

}


Announce_Script_Now_Running

echo -e "\n\nThe installer for Apollia's Perl modules (and some other Perl modules not by Apollia)."



##########################################################
#
#	We open a terminal window at this point and restart 
#	the script, if there was no Argument 1.
#
#	The script ends here if there was no Argument 1.
#


If_Necessary__Open_New_Terminal_Window_and_Relaunch_Self()
{	if [ -z "$1" ]
	# If argument 1 is empty...
	then

		# Need to escape the terminal window title for the command line.
		escaped_enclosed_terminal_window_title=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$terminal_window_title")

		command_line="rxvt -g 80x24 -rv -sb -sr -sl 99999 -title $escaped_enclosed_terminal_window_title -e sh $escaped_enclosed_full_path_to_this_script \"Terminal_Window_Was_Opened_Automatically\" \"$2\" \"$3\" \"$4\""
		
		echo -e "Relaunching this script in a new terminal window:\n\n# $command_line" 

		eval "$command_line"
		exit
	fi
}

If_Necessary__Open_New_Terminal_Window_and_Relaunch_Self "$1" "$2" "$3" "$4"

# Argument 1 can be:
#	"Dont_Open_Window" or "Terminal_Window_Was_Opened_Automatically"
#
# Argument 2 can be:
#	"Dont_Wait_For_Return_At_Scripts_End" or "Wait_for_Return_At_Scripts_End"
#
# Argument 3 is ignored in this script, but is generally "Do_Things_Automatically"
#
# Argument 4 can be "symlink" or "copy".



##########################################################
#
#	If there was an Argument 1, the script can proceed.
#
#
#	Next, we check for Argument 4, which is supposed to indicate
#	whether to symlink to or copy the modules.
#

if [ -z "$4" ] 
then
	# If there's no 4th argument, nothing to change.
	# We'll just use the default config setting in:
	#
	# 	should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying
	
	echo -e "\n\n" 

else # There's a 4th argument, so, we use that instead.

	#echo -e "\n\n4th argument found! $4"
	
	original_config_setting=should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying
	
	case "$4" in
		"true"|"symlink"|"link")
			should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying=true
			;;
		"false"|"copy")
			should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying=false
			;;
		*)	# If text other than the above, we use the original config setting.
			should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying="$original_config_setting"
			;;
	esac
fi



echo -e "\n\n"



if [ "$should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying" = "true" ]
then
	echo -e "Going to make symlink!"
else
	echo -e "Going to copy files into:\n	$full_path_to_tmp_apollia_perl_modules_folder"
fi




##########################################################
#
#	Next, we find out the disk this script is on, and 
#	name of the mountpoint parentdir.
#
# The mountpoint parentdir is /mnt/ in Lucid Puppy 5.2.8 version 004,
# and /media/ in Lighthouse 64 Puppy 6.02 Beta 2.
#
#	The disk and mountpoint parentdir are required to make a full 
#	path out of the relative path stated in:
#
#		relative_path_to_setup_kit_parentdir_of_apollia_perl_modules


Get_Disk_and_Mountpoint_Parentdir_from_Path()
{
	local this_path=$1
	

	##########################################################
	#
	#	Next, we use the "read" command to make an array
	#	containing the disk name and the mountpoint parentdir.
	

	IFS="/"
		# Sets the delimiter for the read command.
		
	read -a pathparts this_path <<< "$this_path"
	
	mountpoint_parentdir="${pathparts[1]}"
	disk="${pathparts[2]}"
	
	#echo -n "  mountpoint parentdir $mountpoint_parentdir   disk $disk"
	
	
}


Get_Disk_and_Mountpoint_Parentdir_from_Path "$THIS_SCRIPT_FOLDER"

mountpoint_parentdir_of_modules="$mountpoint_parentdir"
disk_of_modules="$disk"



##########################################################
#
# 	Now, we can glue together the full path to the location of my
#	(Apollia's) Perl modules.
#


full_path_to_parentdir_of_apollia_perl_modules="/$mountpoint_parentdir_of_modules/$disk_of_modules/$relative_path_to_setup_kit_parentdir_of_apollia_perl_modules"



##########################################################
#
#	Next, we clear away whatever is already at the path for the
#	Apollia Perl modules, and create empty new folders there.
#

echo -e "\n\nRemoving whatever is already at $full_path_to_tmp_apollia_perl_modules_folder..."

escaped_enclosed_full_path_to_tmp_apollia_perl_modules_folder=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$full_path_to_tmp_apollia_perl_modules_folder")

command_line="rm --recursive $escaped_enclosed_full_path_to_tmp_apollia_perl_modules_folder"

echo -e "\n\n# $command_line\n\n"
	
	eval "$command_line"

mkdir --parents "$full_path_to_tmp_apollia_perl_modules_folder/$name_of_grandparentdir_inside_tmp_apollia_perl_modules_folder"

mkdir "$working_dir_for_proc_daemon_perl_module"



##########################################################
#
#	Now, we either create a symlink to the Perl modules, 
#	or we actually copy them to their proper place.
#

escaped_enclosed_full_path_to_parentdir_of_apollia_perl_modules=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$full_path_to_parentdir_of_apollia_perl_modules")



if [ "$should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying" = "true" ]
then
	escaped_enclosed_full_path_to_tmp_apollia_perl_modules_parentdir=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$full_path_to_tmp_apollia_perl_modules_parentdir")
	
	echo -e "\nTrying to make symlink..."
	
	command_line="ln --symbolic $escaped_enclosed_full_path_to_parentdir_of_apollia_perl_modules $escaped_enclosed_full_path_to_tmp_apollia_perl_modules_parentdir"
		# Symlink destination followed by symlink position.
		
	echo -e "\n\n# $command_line\n\n"
	
	eval "$command_line"
	
	echo -e "\nHopefully made symlink!"
		
else # Copying files instead of symlinking.
	escaped_enclosed_full_path_to_tmp_apollia_perl_modules_grandparentdir=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$full_path_to_tmp_apollia_perl_modules_grandparentdir")
	
	echo -e "\n\nTrying to copy files..."
	
	command_line="cp --recursive --dereference $escaped_enclosed_full_path_to_parentdir_of_apollia_perl_modules $escaped_enclosed_full_path_to_tmp_apollia_perl_modules_grandparentdir 2>&1"
	
	echo -e "\n\n# $command_line\n\n"
	
	eval "$command_line"
	
	echo -e "\nHopefully copied files!"
fi



##########################################################
#
#	Nothing left to do but end the script.
#
#	Argument 2 (or the lack thereof) should indicate how
#	the screen will end.
#


End_Script_and_Wait_for_Return()
{
	local wait_for_return
	
	echo -e "\n\n\n\n---";
	
	echo -e "\n\nScript finished!";
	
	echo -e "\n\n$THIS_SCRIPT_FILE_NAME";
	
	echo -e "\n\n$full_path_to_this_script";
	
	echo -e "\n\nYou can press Return (or Enter) to close this window.\n";
	read wait_for_return
	
	exit
}


End_Script_Immediately()
{
	echo -e "\n\n\n\n---\n\n\nImmediate end of $THIS_SCRIPT_FILE_NAME!\n\n"
	echo -e "*(*)*"
	exit
}



if [ -z $2 ] || [ "$2" = "Wait_for_Return_At_Scripts_End" ] # If no 2nd argument, or it's "Wait_for_Return"...
then
	End_Script_and_Wait_for_Return
else 
	End_Script_Immediately
fi

End_Script_and_Wait_for_Return
exit

#
#
#  End of script.
#
############################