#!/bin/sh

# 	Script:                     Prepare for Launch                             
#
#   		             (For Any Puppy Setup Kit Blueprint)                          
# 
#	Version 1.0
#	by Apollia of Astroblahhh.Com.  http://astroblahhh.com/
#
#	Completed Sept. 11, 2014.
#
#
#
#------------------------------------------------------------------------------
#
# Not a standalone script - this is intended to be run via a "source" command
# inside a Launch script which will set the variables $PUPPY_DISTRO_ABBREV, 
# $SETUP_KIT_PARENTDIRS, and $BLUEPRINT_TO_FOLLOW that this script
# needs set for it.
#
# You shouldn't alter anything in this script - there are no configurable settings.
#
# This script creates the /root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/
# folder, and outputs some text files containing info that other Puppy Setup Kit
# scripts will refer to.
#
# These text files are created:
#	
#	Blueprint Used for Puppy Setup Kit.txt
#	Main Disk of Puppy Setup Kit.txt
#	Mountpoint Parentdir of Puppy Setup Kit.txt
#	Abbrev of Puppy Distro.txt
#	Parentdirs of Puppy Setup Kit.txt
#
#------------------------------------------------------------------------------
#
#
#
# Under the GNU General Public License v3.0.
#
# Copyright (C) 2014  Apollia
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
# Contact info:     http://astroblahhh.com/contact-apollia.shtml
#
# ----


#
#
#                  Nothing in this script should be changed.
#
#
####################################################################################################
####################################################################################################
####################################################################################################


#Get_Script_Path_and_Filename

#Announce_Script_Now_Running



##########################################################
#
#	A lot of things depend on things being where they're expected to be, 
#	in the /root/zzzzz-tmp/ folder:
#
#

TMP_FOLDER="/root/zzzzz-tmp"

SETTINGS_FOLDER="$TMP_FOLDER/Apollia's Puppy Setup Kit Settings"



##########################################################
#
#	First, we create a folder like:
#
#		/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings


mkdir --parents "$SETTINGS_FOLDER"
	


##########################################################
#
#	Then, we give it the appropriate permissions.
#
#

chmod --recursive a-rwx,u+rwx "$SETTINGS_FOLDER"
	# --recursive makes this affect both the directory itself and all of its contents.  
	#
	# Takes away read/write/execute permissions from all (owner, group, and world), 
	# then gives owner read/write/execute permissions.



##########################################################
#
#	Then, we create the Parentdirs of Puppy Setup Kit.txt file.
#
#

echo -n $SETUP_KIT_PARENTDIRS > "$SETTINGS_FOLDER/Parentdirs of Puppy Setup Kit.txt"
	# -n makes it so there's no newline printed at the end of the line.
	#
	# The > causes the results of "echo -n $SETUP_KIT_PARENTDIRS" to be output to a
	# file.
	#
	# The above outputs whatever $SETUP_KIT_PARENTDIRS is set to ("Meadow" by default)
	# to a text file located at someplace like:
	#
	#       /root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Lup5284/Parentdirs of Puppy Setup Kit.txt
	
	

##########################################################
#
#	Now we give that the appropriate permissions.
#
#
	
chmod a-rwx,u+r "$SETTINGS_FOLDER/Parentdirs of Puppy Setup Kit.txt"
	# Takes away read/write/execute permissions from all, then gives owner read permissions.



##########################################################
#
#	Now we find out this script's folder.
#
#

THIS_SCRIPT_FOLDER="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"



##########################################################
#
#	Next, we find out the disk this script is on, and 
#	name of the mountpoint parentdir.
#
# The mountpoint parentdir is /mnt/ in Lucid Puppy 5.2.8 version 004,
# and /media/ in Lighthouse 64 Puppy 6.02 Beta 2.
#
#


Get_Disk_and_Mountpoint_Parentdir_from_Path()
{
	local this_path=$1
	

	##########################################################
	#
	#	Next, we use the "read" command to make an array
	#	containing the disk name and the mountpoint parentdir.
	

	IFS="/"
		# Sets the delimiter for the read command.
		
	read -a pathparts this_path <<< "$this_path"
	
	mountpoint_parentdir="${pathparts[1]}"
	disk="${pathparts[2]}"
	
	#echo -n "  mountpoint parentdir $mountpoint_parentdir   disk $disk"

}


Get_Disk_and_Mountpoint_Parentdir_from_Path "$THIS_SCRIPT_FOLDER"



##########################################################
#
#	Then, we create the Main Disk of Puppy Setup Kit.txt file.
#
#

echo -n $disk > "$SETTINGS_FOLDER/Main Disk of Puppy Setup Kit.txt"
	# -n makes it so there's no newline printed at the end of the line.
	#
	# The > causes the results of "echo -n $disk" to be output to a
	# file.
	#
	# The above outputs whatever $disk is set to (maybe something like "sda1")
	# to a text file located at someplace like:
	#
	#       /root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Lup5284/Main Disk of Puppy Setup Kit.txt
	

chmod a-rwx,u+r "$SETTINGS_FOLDER/Main Disk of Puppy Setup Kit.txt"
	# Takes away read/write/execute permissions from all, then gives owner read permissions.
	
	

##########################################################
#
#	And, we create the Main Disk of Puppy Setup Kit.txt file.
#
#

echo -n $mountpoint_parentdir > "$SETTINGS_FOLDER/Mountpoint Parentdir of Puppy Setup Kit.txt"
	# -n makes it so there's no newline printed at the end of the line.
	#
	# The > causes the results of "echo -n $mountpoint_parentdir" to be output to a
	# file.
	#
	# The above outputs whatever $mountpoint_parentdir is set to (most likely "mnt"
	# or "media") to a text file located at someplace like:
	#
	# /root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Lup5284/Mountpoint Parentdir of Puppy Setup Kit.txt
	

chmod a-rwx,u+r "$SETTINGS_FOLDER/Mountpoint Parentdir of Puppy Setup Kit.txt"
	# Takes away read/write/execute permissions from all, then gives owner read permissions.
	
	
	
##########################################################
#
#	And, the Blueprint Used for Puppy Setup Kit.txt file.
#
#

echo -n $BLUEPRINT_TO_FOLLOW > "$SETTINGS_FOLDER/Blueprint Used for Puppy Setup Kit.txt"
	# -n makes it so there's no newline printed at the end of the line.
	#
	# The > causes the results of "echo -n $BLUEPRINT_TO_FOLLOW" to be output to a
	# file.
	#
	# The above outputs whatever $mountpoint_parentdir is set to (most likely "mnt"
	# or "media") to a text file located at someplace like:
	#
	# /root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Lup5284/Blueprint Used for Puppy Setup Kit.txt
	

chmod a-rwx,u+r "$SETTINGS_FOLDER/Blueprint Used for Puppy Setup Kit.txt"
	# Takes away read/write/execute permissions from all, then gives owner read permissions.



##########################################################
#
#	And, the Abbrev of Puppy Distro.txt file.
#
#

echo -n $PUPPY_DISTRO_ABBREV > "$SETTINGS_FOLDER/Abbrev of Puppy Distro.txt"
	# -n makes it so there's no newline printed at the end of the line.
	#
	# The > causes the results of "echo -n $BLUEPRINT_TO_FOLLOW" to be output to a
	# file.
	#
	# The above outputs whatever $mountpoint_parentdir is set to (most likely "mnt"
	# or "media") to a text file located at someplace like:
	#
	# /root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Lup5284/Blueprint Used for Puppy Setup Kit.txt

chmod a-rwx,u+r "$SETTINGS_FOLDER/Abbrev of Puppy Distro.txt"
	# Takes away read/write/execute permissions from all, then gives owner read permissions.




##########################################################
#
#	And lastly, a very important step - installing the ApolliaLib modules.
#
#

path_to_apollialib_installer="/$mountpoint_parentdir/$disk/$SETUP_KIT_PARENTDIRS/Woodland/Any_Pup/Puppy Setup Kit Launcher/Install Apollia's Perl Modules/Install Apollia's Perl Modules and Other Perl Modules.sh"

escaped_path_to_apollialib_installer=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$path_to_apollialib_installer")



symlink_or_copy="copy"		# Default setting


if [ "$should_make_symlink_to_folder_of_apollialib_modules_instead_of_copying" == "true" ]
then
	symlink_or_copy="symlink"
fi



command_line="sh $escaped_path_to_apollialib_installer 'Dont_Open_Window' 'Dont_Wait_For_Return_At_Scripts_End' 'Do_Things_Automatically' \"$symlink_or_copy\""

eval "$command_line"



#
#
#  End of script.
#
############################