#!/bin/sh

# 	Script:                 Switch Meadow and Blueprint                          
#
#                       (For Any Puppy Setup Kit Blueprint)                          
# 
#	Version 1.0
#	by Apollia of Astroblahhh.Com.  http://astroblahhh.com/
#
#	Completed Sept. 17, 2014.
#
#
#
#------------------------------------------------------------------------------
#
# Based on Prepare for Launch.sh.
#
# Not a standalone script - this is intended to be run via a "source" command
# inside a Switch Meadow Repo script (which is almost just like a Launch script)
# which will set various variables this script needs set for it.
#
# The difference is, a Switch Meadow Repo script doesn't actually launch the
# blueprint - it just changes the Puppy Setup Kit settings in /root/zzzzz-tmp
# to make it so you can easily start working with files in a different Meadow 
# repository. 
#
# You shouldn't alter anything in this script - there are no configurable settings.
#
# This script outputs some text files containing info that other Puppy Setup Kit
# scripts will refer to.
#
# These text files are created:
#	
#	Blueprint Used for Puppy Setup Kit.txt
#	Main Disk of Puppy Setup Kit.txt
#	Mountpoint Parentdir of Puppy Setup Kit.txt
#	Abbrev of Puppy Distro.txt
#	Parentdirs of Puppy Setup Kit.txt
#
# Then, in /root/zzzzz-tmp/, this script puts a symlink to, or else copies,
# the ApolliaLib modules which are in the current Meadow repository.
#
#------------------------------------------------------------------------------
#
#
#
# Under the GNU General Public License v3.0.
#
# Copyright (C) 2014  Apollia
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
# Contact info:     http://astroblahhh.com/contact-apollia.shtml
#
# ----


#
#
#                  Nothing in this script should be changed.
#
#
####################################################################################################
####################################################################################################
####################################################################################################



##########################################
#
#
# 	Start of function 
#
#
#	Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes()
#
#

Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes()
{	
	local quotes_escaped

	quotes_escaped=$(echo "$1" | sed -e "s/'/'\"'\"'/g")

	echo "'$quotes_escaped'"
}

#
#
#	End of function 
#
#	Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes()
#
#
###########################################################



##########################################################
#
#	Now we find out this script's folder.
#
#

THIS_SCRIPT_FOLDER="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"



##########################################################
#
#	Next, we run the Prepare for Launch script.
#
#


cd "$THIS_SCRIPT_FOLDER"

source "./Prepare for Launch.sh"


parentdirs_of_puppy_setup_kit=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Parentdirs of Puppy Setup Kit.txt")

setup_kit_folder_name=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Abbrev of Puppy Distro.txt")

setup_kit_mountpoint_parentdir=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Mountpoint Parentdir of Puppy Setup Kit.txt")

setup_kit_disk=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Main Disk of Puppy Setup Kit.txt")

blueprint=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Blueprint Used for Puppy Setup Kit.txt")


Xdialog --title "Results of Switch Meadow and Blueprint" --msgbox "parentdirs_of_puppy_setup_kit: $parentdirs_of_puppy_setup_kit\n\nsetup_kit_disk: $setup_kit_disk\n\nPuppy Setup Kit: $setup_kit_folder_name\n\nBlueprint: $blueprint" 30 100


#
#
#  End of script.
#
############################