# ApolliaLib :: Common :: Dragdrop.pm
#
# Not every script uses drag & drop, but it's good to be able 
# to easily make any script capable of ignoring drag & drop,
# to make it easier to avoid scripts being accidentally run.
#
# So, that's why I made drag & drop-related stuff part of the 
# ApolliaLib :: Common modules.
#
# There's actually no certain way for a script to distinguish between 
# drag & drop arguments and arguments typed on a command line.
#
# (See also: Arguments.pm)


use strict;
use warnings;


package ApolliaLib::Common::Dragdrop;



################################################################
#
#                         Exported Stuff
#
# This bit specifies which parts of this module are made available to
# scripts that use the following line:
#
# 	use ApolliaLib::Common::Dragdrop;
#
#
# I pasted much of the below from:
#
# 	http://perldoc.perl.org/perlmod.html


BEGIN 
{
	require Exporter;

	#set the version for version checking
	our $VERSION = 1.00;

	#Inherit from Exporter to export functions and variables
	our @ISA = qw(Exporter);

	#Functions and variables which are exported by default
	our @EXPORT = qw(  
		Get_Either_Dragdrop_Args_or_Config_Args
		Get_Dragdrop_Args
		);

	#Functions and variables which can be optionally exported
	our @EXPORT_OK = qw(
		
		);
}



#
#                End of Exported Stuff section. 
#
#
################################################################



##################################################
#
#	Needed imports from other modules
#

use ApolliaLib::Common::End_Script qw ( 
	End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify
	End_Script 
	);

use ApolliaLib::Common::Arguments (
	"Get_Nonignored_Args_from_ARGV" 
	);
	
#
#	End of Needed imports from other modules
#
##################################################




################################################################
#
#	Start of stuff unique to this module
#


sub Get_Dragdrop_Args
{


	#----
	my @things_in_config;
	
	my $ref_to_things_probably_dragdropped;
	
	my @things_probably_dragdropped;
	my @things_to_return;
	
	my $last_words;
	
	#@@@@
	$ref_to_things_probably_dragdropped=Get_Nonignored_Args_from_ARGV();
	@things_probably_dragdropped = @$ref_to_things_probably_dragdropped;



	##############################
	
	
	# If the script has gotten to this point, then we know it has already
	# gotten past the argument quantity checks - otherwise, the script 
	# would have aborted already.
	#
	# So, any dragdrop arguments (or command line arguments) can be
	# safely accepted as valid.
	#
	# It the script accepts dragdrop (command line) arguments, then,
	# those are given precedence over arguments specified in the
	# config settings.
	#
	# Arguments specified in the config settings are only used
	# if there are no dragdrop (command line) arguments.
	#
	#
	# Again, there's actually no certain way for a script to distinguish 
	# between drag & drop arguments and arguments typed on a command line. 
	
	if (@things_probably_dragdropped)
	{	@things_to_return = @things_probably_dragdropped;

	}
	else # No dragdropped things.
	{	$last_words="\n\nNothing to do - nothing dragged and dropped!  Aborting.";
		
		
		#!!!!
		End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
	}
	
	
	#!!!!
	return (@things_to_return);
}



sub Get_Either_Dragdrop_Args_or_Config_Args
{
	my $Ref_to_array_of_things_in_config=$_[0];


	#----
	my @things_in_config;
	
	my $ref_to_things_probably_dragdropped;
	
	my @things_probably_dragdropped;
	my @things_to_return;
	
	my $which_things_used;
	
	my $last_words;
	
	#@@@@	
	@things_in_config=@$Ref_to_array_of_things_in_config;	
	$ref_to_things_probably_dragdropped=Get_Nonignored_Args_from_ARGV();
	@things_probably_dragdropped = @$ref_to_things_probably_dragdropped;



	##############################
	
	
	# If the script has gotten to this point, then we know it has already
	# gotten past the argument quantity checks - otherwise, the script 
	# would have aborted already.
	#
	# So, any dragdrop arguments (or command line arguments) can be
	# safely accepted as valid.
	#
	# It the script accepts dragdrop (command line) arguments, then,
	# those are given precedence over arguments specified in the
	# config settings.
	#
	# Arguments specified in the config settings are only used
	# if there are no dragdrop (command line) arguments.
	#
	#
	# Again, there's actually no certain way for a script to distinguish 
	# between drag & drop arguments and arguments typed on a command line. 
	
	if (@things_probably_dragdropped)
	{	@things_to_return = @things_probably_dragdropped;
		$which_things_used = "Dragdrop";
	}
	else # No dragdropped things.
	{	if (@things_in_config)
		{	@things_to_return=@things_in_config;
			$which_things_used="Config";
		}
		else # No things in config either.
		{	
			$last_words="\n\nNothing to do - nothing dragged and dropped, and no files listed even in the config settings!  Aborting.";
			
			
			#!!!!
			End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
		}
	}
	
	#!!!!
	return (\@things_to_return, $which_things_used);
}



1;