# ApolliaLib :: Common :: Misc.pm
#
# Things that I (Apollia) commonly use in my Perl scripts.
#
# This file contains miscellaneous basics like true/false constants,
# a dollar sign variable, and various common functions like string
# escapers.  And other things which perhaps it might make sense to 
# put elsewhere.


use strict;
use warnings;


package ApolliaLib::Common::Misc;



################################################################
#
#                         Exported Stuff
#
# This bit specifies which parts of this module are made available to
# scripts that use the following line:
#
# 	use ApolliaLib::Common::Misc;
#
#
# I pasted much of the below from:
#
# 	http://perldoc.perl.org/perlmod.html


BEGIN 
{
	require Exporter;

	#set the version for version checking
	our $VERSION = 1.00;

	#Inherit from Exporter to export functions and variables
	our @ISA = qw(Exporter);

	#Functions and variables which are exported by default
	our @EXPORT = (  
		"true", 
		"false",
		'$dollar_sign',
		"necho",
		"Escape_Single_Quotes_for_Bash",
		
		"Escape_Quotes",
		
		#Command line
		"Display_and_Do_Command_Line_and_Result",
		"Display_and_Do_Command_Line",
		
	
		"is_integer",
		"is_float",
		
		"String_Contains_Space",
		"String_Consists_of_Nothing_but_Single_Quotes_or_Spaces",
		
		"String_Contains_",
		
		
		# String manipulation
		"Add_Slash_If_Needed_To_",
		
		
		# Array-related
		"Get_Arrin_of_String_in_Array",
		"Get_Random_Item_from_Array_",
		
		
		
		# Array manipulation
		"Prefix_Array_Values_With",
		
		# Hash manipulation
		"Prefix_Hash_Keys_With",
		
		
		# Text display:
		
		"Print_Array_Spacedly",
		"Print_Comma_Separated_Array",
		"Print_Array_Indentedly",
		
		"Print_Hash_Indentedly",
		
		"Print_Octal_Value_Properly",
		
		
		# Unit conversion
		"Convert_MiB_to_Bytes",
		"Convert_Bytes_to_MiB"
		);

	#Functions and variables which can be optionally exported
	our @EXPORT_OK = qw(
	
		);
}



#
#                End of Exported Stuff section. 
#
#
################################################################




################################################################
#
#	Start of stuff unique to this module
#



################
#
#   Constants for readability

use constant false => 0;
use constant true  => 1;

our $dollar_sign="\$";

#
#   End of Constants for readability
#
################



# 18:28 04/15/2014. 23:54 04/19/2014.  These next two functions are modified version of functions from:
# http://stackoverflow.com/questions/12647/how-do-i-tell-if-a-variable-has-a-numeric-value-in-perl


sub is_integer 
{
	my $possible_integer=$_[0];
	


	##############################

	if ( $possible_integer =~ /^[+-]?\d+$/ )
	{	
		
		#!!!!
		return true;
	}
	else
	{	
		
		#!!!!
		return false;
	}
}

# From http://stackoverflow.com/questions/12647/how-do-i-tell-if-a-variable-has-a-numeric-value-in-perl
#sub is_integer {
#   defined $_[0] && $_[0] =~ /^[+-]?\d+$/;
#}



sub is_float 
{	    
   my $possible_float=$_[0];
    
    
    
	##############################
	
	if ( $possible_float =~ /^[+-]?\d+(\.\d+)$/ )
	{	
		
		#!!!!
		return true;
	}
	else
	{	
		
		#!!!!
		return false;
	}
  
}

# From http://stackoverflow.com/questions/12647/how-do-i-tell-if-a-variable-has-a-numeric-value-in-perl
#sub is_float {
#   defined $_[0] && $_[0] =~ /^[+-]?\d+(\.\d+)?$/;
#}



sub Add_Slash_If_Needed_To_
{
	my $this_string=$_[0];

	
	#----
	my $last_char;
	
	
	
	##############################
	
	$last_char = substr($this_string, length($this_string)-1,1);
	
	if ($last_char ne "/")
	{	$this_string .= "/";
	}
	
	
	#!!!!
	return $this_string;
	
}



sub Get_Random_Item_from_Array_
{
	# Haven't tested if this will work with arrays that contain references.
	
	my $ref_to_array=$_[0];
	
	
	#----
	my @array;
	my $count_of_array_items;
	my $random_arrin;
	my $chosen_item;
	
	#@@@@
	@array=@$ref_to_array;	
	$count_of_array_items=@array;
	
	
	
	##############################
	
	$random_arrin=rand($count_of_array_items);
	$chosen_item=$array[$random_arrin];


	#!!!!
	return $chosen_item;	
}



sub Get_Arrin_of_String_in_Array
{
	my $string_to_search_for=$_[0];
	my $ref_to_array=$_[1];
	
	
	#----
	my @array;
	my $arrin_of_string_to_search_for;
	
	#@@@@
	@array=@$ref_to_array;


	
	##############################
		
	# From http://www.perlmonks.org/?node_id=75663 -
	( $arrin_of_string_to_search_for )= grep { $array[$_] eq $string_to_search_for } 0..$#array;

	
	#!!!!
	return $arrin_of_string_to_search_for;
	
}



sub Display_and_Do_Command_Line
{	
	my $command_line=$_[0];
	
	
	
	##############################
	
	print "\n\n\n# $command_line";
	
	print "\n\n\n";
	
	system ($command_line);
	
}



sub Display_and_Do_Command_Line_and_Result
{	
	my $command_line=$_[0];


	#----
	my $result;
	
	
	
	##############################
	
	#$command_line = $command_line . " 2>&1";
		
	print "\n\n\n# $command_line";
	
	print "\n\n";
	
	$result=`$command_line`;
	
	print "\n";
	
#	print "Result:\n";
	if (defined $result)
	{
		print "$result";
	}
	
	#!!!!
	return $result;
	
}















sub String_Contains_
{
	my $needle=$_[0];
	my $haystack=$_[1];
	

	#----
	my $position_of_needle;
	
	
	
	##############################
		
	$position_of_needle = index($haystack, $needle);
	
	if ($position_of_needle==-1)
	{	
		
		#!!!!
		return false;
	}
	
	
	#!!!!
	return true;	
}



sub Locate_String_In_
{ # 09:51 05/26/2014. not yet used anywhere.
	my $haystack=$_[0];
	my $needle=$_[1];
	
	
	#----
	my $position_of_needle;
	
	
	
	##############################
		
	$position_of_needle = index($haystack, $needle);
	

	#!!!!
	return $position_of_needle;
}



sub String_Contains_Space
{
	my $string=$_[0];


	#----
	my $position_of_space;



	##############################
	
	$position_of_space = index($string, " ");
	
	if ($position_of_space==-1)
	{	

		#!!!!
		return false;
	}


	#!!!!
	return true;	
}



sub Escape_Single_Quotes_for_Bash
{
	my $string=$_[0];


	#----
	my $result;
	
	#@@@@
	$result=$string;
	
	
	
	##############################
		
	if (defined $result)
	{
		$result=~s/'/'\"'\"'/g;
	}
	else
	{	$result="";
		print "\n\n\n\nWARNING: An undefined string was passed to Escape_Single_Quotes_for_Bash()!";
	}
	

	#!!!!
	return $result;
}



sub Prefix_Array_Values_With
{	
	my $prefix=$_[0];
	my $ref_to_array=$_[1];
	
	
	#----
	my @array;
	my $count_of_array_items;
	my $arrin;
	my $array_value;
	my $new_array_value;
	
	#@@@@
	@array=@$ref_to_array;
	
	$count_of_array_items=@array;
	$arrin=0;



	##############################
	
	while ($arrin<$count_of_array_items)
	{	
		$array_value=$array[$arrin];
		
		$new_array_value = $prefix . $array_value;
		
		$array[$arrin]=$new_array_value;
		
		$arrin++;
		
	}
	#print "Done prefixing with Prefix_Array_Values_With()!";
	
	#Print_Array_Indentedly(\@array);

	
	#!!!!
	return \@array;
}



sub Prefix_Hash_Keys_With
{
	my $prefix=$_[0];
	my $ref_to_hash=$_[1];	
	
	
	#----
	my %hash;
	my $key;
	my $new_hash_key;
	
	#@@@@
	%hash=%$ref_to_hash;



	##############################
	
	foreach $key (keys %hash)
	{
		$new_hash_key = $prefix . $key;
		$hash{$new_hash_key} = $hash{$key};
		delete $hash{$key};
	}
	
	#Print_Hash_Indentedly(\%hash);
	#print "\n\n\n";
	

	#!!!!
	return \%hash;
}



sub Escape_Quotes
{
	my $string=$_[0];


	#----
	my $result;
	
	#@@@@
	$result=$string;
	
	
	
	##############################
		
	$result=~s/"/\\"/g;
	
	
	#!!!!
	return $result;
}



sub Print_Hash_Indentedly
{	
	my $ref_to_hash=$_[0];


	#----
	my %hash;
	my $this_line;
	my $result;
	
	#@@@@	
	%hash=%$ref_to_hash;
	$result="";
	
	
	
	##############################
	
	for (keys %hash )
	{	
		$this_line="\n\n[$_] => $hash{$_}";
		print $this_line;
		
		$result = $result . $this_line;
	};
	

	#!!!!
	return $result;
}



sub necho
{	
	my $string=$_[0];



	##############################
	
	print "\n\n\n\n\n$string\n\n\n\n";
	
}



sub Convert_Bytes_to_MiB
{
	my $bytes=$_[0];
	
	
	#----
	my $result;
	
	
	
	##############################
	
	$result = $bytes / 1048576;
	
	
	#!!!!	
	return $result;
}



sub Convert_MiB_to_Bytes
{
	my $MiB=$_[0];

	
	#----
	my $result;
	
	
	
	##############################
	
	$result = $MiB * 1048576;
	
	
	#!!!!	
	return $result;
}



sub Print_Octal_Value_Properly
{	
	my $octal_value=$_[0];
	
	
	
	##############################
		
	printf( "%o", $octal_value); 
	
}



sub String_Consists_of_Nothing_but_Single_Quotes_or_Spaces
{	
	my $string=$_[0];
	

	#----
	my $filtered_string;

	#@@@@
	$filtered_string=$string;
	


	##############################
	
	$filtered_string=~s/\'|\s//g;
	
	
	if (!$filtered_string)
	{	
		
		#!!!!
		return true;
	}
	
	
	#!!!!
	return false;
	
}



sub Print_Comma_Separated_Array
{	
	my $ref_to_array=$_[0];
	my $should_be_silent=$_[1];
	
	
	#----
	my @array;
	my $array_item;
	my $this_line;
	my $result;

	
	#@@@@
	@array=@$ref_to_array;
	
	if (!defined $should_be_silent)
	{	$should_be_silent=false;
	}		
	
	$result="";
	
	
	
	##############################
	
	foreach $array_item (@array)
	{	
		$this_line="$array_item, ";
		
		$result = $result . $this_line;
		
	}
	
	chop($result);
	chop($result);
	
	
	if ( !$should_be_silent)
	{
		print $result;
	}
		
	
	#!!!!
	return $result;
	
}



sub Print_Array_Spacedly
{	
	my $ref_to_array=$_[0];
	my $should_be_silent=$_[1];
	
	
	#----
	my @array;
	my $array_item;
	my $this_line;
	my $result;

	
	#@@@@
	@array=@$ref_to_array;
	
	if (!defined $should_be_silent)
	{	$should_be_silent=false;
	}		
	
	$result="";
	
	
	
	##############################
	
	foreach $array_item (@array)
	{	
		$this_line=" $array_item";
		
		if ( !$should_be_silent)
		{
			print $this_line;
		}
		$result = $result . $this_line;
		
	}
	

	#!!!!
	return $result;
	
}



sub Print_Array_Indentedly
{
	my $ref_to_array=$_[0];
	my $should_be_silent=$_[1];

	
	#----
	my @array;
	my $array_item;
	my $this_line;
	my $result;

	
	#@@@@
	@array=@$ref_to_array;
	
	if (!defined $should_be_silent)
	{	$should_be_silent=false;
	}	
	
	$result="";

	
	
	##############################
	
	foreach $array_item (@array)
	{	
		$this_line="\n\n	$array_item";
		
		if ( !$should_be_silent)
		{
			print $this_line;
		}
		$result = $result . $this_line;
		
	}
	
	
	#!!!!
	return $result;
}



1;