# ApolliaLib :: Common :: Relaunch_in_Terminal_Window.pm
#
# Stuff related to relaunching scripts in a terminal window so you can see output.


use strict;
use warnings;


package ApolliaLib::Common::Relaunch_in_Terminal_Window;



################################################################
#
#                         Exported Stuff
#
# This bit specifies which parts of this module are made available to
# scripts that use the following line:
#
# 	use ApolliaLib::Common::Relaunch_in_Terminal_Window;
#
#
# I pasted much of the below from:
#
# 	http://perldoc.perl.org/perlmod.html


BEGIN 
{
	require Exporter;

	#set the version for version checking
	our $VERSION = 1.00;

	#Inherit from Exporter to export functions and variables
	our @ISA = qw(Exporter);

	#Functions and variables which are exported by default
	our @EXPORT = qw(  
		Possibly_Open_New_Terminal_Window_and_Relaunch_Self 
		Typical_Script_Launch
		);

	#Functions and variables which can be optionally exported
	our @EXPORT_OK = qw(
	
		);
}



#
#                End of Exported Stuff section. 
#
#
################################################################



##################################################
#
#	Needed imports from other modules
#


use ApolliaLib::Common::Misc qw ( 
	true 
	false 
	$dollar_sign 
	Escape_Quotes 
	Escape_Single_Quotes_for_Bash 
	Print_Array_Indentedly
	necho
	);

use ApolliaLib::Common::Script_Details qw ( 
	$Launched_Script_Details
	$Launched_Script
	);

use ApolliaLib::Common::User_Prompted_Actions (
	"Ask_To_Do_Action",
	"Pause_Until_User_Presses_Enter"
	);

use ApolliaLib::Common::Settings qw ( 
	$ApolliaLib_Settings
	$ApolliaLib_Settings_say_we
	);
	
use ApolliaLib::Common::Arguments qw ( 
	Remove_Now_Unneeded_Clutter_from_ARGV
	Determine_Script_Ending_Type_Using_Argv
	Determine_Automaticness_Using_Argv
	Is_Recognized_ApolliaLib_Script_Endingtype_Arg
	Is_Recognized_ApolliaLib_Arg
	Get_Nonignored_Args_from_ARGV
	);
	
	
	
use ApolliaLib::Common::End_Script qw ( 
	
	End_Script_Immediately
	End_Script_with_Autoclose
	End_Script_and_Wait_for_Return
	End_Script
	End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify
	);

use ApolliaLib::Common::X_Dialog;

#
#	End of Needed imports from other modules
#
##################################################




################################################################
#
#	Start of stuff unique to this module
#



sub Abort_Script_Before_Terminal_Window_Launch_If_Appropriate
{	
	
	
	#----
	my $last_words;
	

	
	##############################
	
	if ($ApolliaLib_Settings_say_we->should_arbitrarily_abort_script_before_terminal_window_launch)
	{	$last_words="\n\nAborting, since your settings say this script should abort before the terminal window launch!";
	
		
		End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
	}
	
	if 	(	$ApolliaLib_Settings_say_we->should_abort_if_private_script_is_run_from_a_public_location 
			&& 
			$ApolliaLib_Settings_say_we->should_warn_if_private_script_is_run_from_a_public_location==false
		)
	{	
		
		#!!!!
		Abort_and_or_Warn_if_Privacy_Issue_Found();
		# Done before the terminal window gets launched, so it will look like nothing happens.
	}
	

	if ($ApolliaLib_Settings_say_we->should_windowlessly_abort_if_wrong_quantity_of_nonignored_arguments_is_found)
	{	
		
		#!!!!
		Abort_if_Arg_Quantity_Issue_Found();
	}
	
}



sub Abort_and_or_Warn_if_Privacy_Issue_Found
{
	
	
	#----
	my $last_words;


	
	##############################
	
	if ($Launched_Script_Details->privacy_level eq "Private")
	{	
		if ($Launched_Script_Details->privacy_level_of_current_location eq "Public")
		{
			if ($ApolliaLib_Settings_say_we->should_warn_if_private_script_is_run_from_a_public_location)
			{	$last_words = "\n\n\n\nWarning: This script's privacy level is set to Private, but this script is currently located in a public, non-TrueCrypted location!";
				
				if ($ApolliaLib_Settings_say_we->should_abort_if_private_script_is_run_from_a_public_location)
				{	$last_words = $last_words . "\n\n\n\nAborting, because your settings don't allow private scripts to be run if they're found in public locations!";

				
					#!!!!
					End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
				}
				else
				{	print $last_words;
					#Pause_Until_User_Presses_Enter();
					
					
					#!!!!
					Ask_To_Do_Action("continue running this script", "Don't display skip this step text");
					
				}
			}
			
			if ($ApolliaLib_Settings_say_we->should_abort_if_private_script_is_run_from_a_public_location)
			{	
				
				
				#!!!!
				End_Script_Immediately();
					
			}
		}
	}
}



sub Abort_if_Arg_Quantity_Issue_Found
{	
	
	#----
	my $last_words;
	my $last_words_without_arg_list;
	
	my $ref_to_nonignored_args_from_ARGV;
	my @nonignored_args_from_ARGV;
	my $min_number_of_args_other_than_ignored_args;
	my $max_number_of_args_other_than_ignored_args;
	my $count_of_nonignored_args_from_ARGV;
	
	#@@@@	
	$min_number_of_args_other_than_ignored_args=$ApolliaLib_Settings->min_number_of_args_other_than_ignored_args;
	
	$max_number_of_args_other_than_ignored_args=$ApolliaLib_Settings->max_number_of_args_other_than_ignored_args;
	

	$ref_to_nonignored_args_from_ARGV=Get_Nonignored_Args_from_ARGV();
	@nonignored_args_from_ARGV=@$ref_to_nonignored_args_from_ARGV;
	$count_of_nonignored_args_from_ARGV=@nonignored_args_from_ARGV;
	
	
	
	##############################
	
	if 	(	$count_of_nonignored_args_from_ARGV < $min_number_of_args_other_than_ignored_args 
			|| 
			$count_of_nonignored_args_from_ARGV > $max_number_of_args_other_than_ignored_args
		)
	{	
		
		if ($count_of_nonignored_args_from_ARGV < $min_number_of_args_other_than_ignored_args )
		{
			$last_words_without_arg_list = "\n\n\n\nAborting, because your settings require a minimum of $min_number_of_args_other_than_ignored_args arguments, and only $count_of_nonignored_args_from_ARGV non-ignored arguments were found!";
		}
		elsif ( $count_of_nonignored_args_from_ARGV > $max_number_of_args_other_than_ignored_args )
		{	$last_words_without_arg_list = "\n\n\n\nAborting, because your settings require a maximum of $max_number_of_args_other_than_ignored_args arguments, and $count_of_nonignored_args_from_ARGV non-ignored arguments were found!";
		}		
		
		$last_words = $last_words_without_arg_list . "\n\nAll arguments:\n\n";
				
		$last_words = $last_words . Print_Array_Indentedly(\@ARGV, "Be Silent");
		
		
		$last_words = $last_words . $last_words_without_arg_list;
		
		
		#!!!!
		End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
		
	}
}



sub Abort_if_ApolliaLib_Version_Issue_Found
{
	
	
	#----
	my $last_words;
	
	
	
	##############################
	

	if (	$ApolliaLib_Settings_say_we->should_abort_if_ApolliaLib_version_not_specified 
			||
			$ApolliaLib_Settings_say_we->should_warn_if_ApolliaLib_version_not_specified 
		)
	{
		if ( defined $Launched_Script->script_ApolliaLib_version && $Launched_Script->script_ApolliaLib_version eq "Not Yet Specified" )
		{
			
			if ( $ApolliaLib_Settings_say_we->should_abort_if_ApolliaLib_version_not_specified )
			{
				$last_words="\n\n\n\nAborting because no ApolliaLib module version was specified for this script, and your settings say to abort if that's the case!\n\n";
				
				
				#!!!!
				End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
			}
			
			if ( $ApolliaLib_Settings_say_we->should_warn_if_ApolliaLib_version_not_specified )
			{	print "\n\n\n\n\n\nWARNING: Thid script doesn't specify an ApolliaLib module version, and your settings say to warn about this!";
			
				#Pause_Until_User_Presses_Enter();
				
				#!!!!
				Ask_To_Do_Action("continue running this script", "Don't display skip this step text");
				
			}
			
		}
	}
	else
	{	necho "no problem";
	}
	
}



sub Abort_if_Script_Was_Successfully_Run_Before_This_Run
{
	
	
	#----
	my $last_words;
	my $ref_to_note_text_array;
	my @note_text;
	
	
	
	##############################
	
	if 	( 	$ApolliaLib_Settings_say_we->should_abort_script_if_it_was_successfully_completed_before_this_run 
			|| 
			$ApolliaLib_Settings_say_we->should__if_script_was_successfully_completed_before_this_run__warn_and_ask_if_user_wants_to_continue 
		)
	{	
	
		$Launched_Script->Find_Out_If_This_Script_Was_Already_Completed_Before_This_Run();
		
		
		if ($Launched_Script->was_already_completed_before_this_run)
		{	
			$Launched_Script_Details->Store_Path_of_Note_of_Successful_Completion();
			
			$ref_to_note_text_array=$Launched_Script->Retrieve_Text_from_Completion_Note_File();
			@note_text=@$ref_to_note_text_array;
			
			
			
			if ($ApolliaLib_Settings_say_we->should_abort_script_if_it_was_successfully_completed_before_this_run )
			{
				$last_words="\n\n\n\nAborting, since this script was apparently already run successfully before!\n\n";
				
				for (@note_text)
				{	$last_words = $last_words . $_;
				}
				
				
				#!!!!
				End_Script_For_Problem_Using_Whatever_Ending_Type_The_Settings_Specify($last_words);
			}
			elsif ( $ApolliaLib_Settings_say_we->should__if_script_was_successfully_completed_before_this_run__warn_and_ask_if_user_wants_to_continue )
			{	
				print "\n\n\n\n\n\nWARNING: This script was apparently already run successfully before!  ";
				
				print @note_text;
				
				print "\n\n\n\nDo you want to continue running this script?";
				
				
				#!!!!
				Ask_To_Do_Action("continue running this script", "Don't display skip this step text");
				
			}
		}
		
	}
}



sub Abort_Script_If_Appropriate
{	
	
	
	#----
	my $First_Argv_Arg;	
	my $script_was_probably_double_clicked;
	


	##############################
	
	
	#!!!!
	Abort_if_ApolliaLib_Version_Issue_Found();
	
	
	#!!!!
	Abort_and_or_Warn_if_Privacy_Issue_Found();
		# Done after the terminal window gets launched, so the user can read the warning or
		# read why the script was aborted.
	
	
	#!!!!
	Abort_if_Arg_Quantity_Issue_Found();


	#!!!!	
	Abort_if_Script_Was_Successfully_Run_Before_This_Run();

}



sub Build_Command_Line_That_Relaunches_Script_in_New_Terminal_Window
{
	
	#----
	my $terminal_window_title_with_escaped_single_quotes_for_bash;
		
	my $all_argv_args;
	my $arg;
	
	my $command_line_without_self_repeat;
	my $escaped_command_line_without_self_repeat;
	
	my $command_line_with_self_repeat;

	#@@@@
	$all_argv_args = "";
	
	$terminal_window_title_with_escaped_single_quotes_for_bash=Escape_Single_Quotes_for_Bash($ApolliaLib_Settings->terminal_window_title);
	


	##############################
	
	foreach $arg (@ARGV)
	{	
		if ( Is_Recognized_ApolliaLib_Arg($arg) )
		{	next;
		}
		$arg=Escape_Single_Quotes_for_Bash($arg);
		$all_argv_args = $all_argv_args . " '$arg' ";	
	}
	
	
	$command_line_without_self_repeat = $ApolliaLib_Settings->Start_of_Command_to_Launch_Terminal_Window . " '$terminal_window_title_with_escaped_single_quotes_for_bash' -e perl '" . $Launched_Script_Details->full_path_with_escaped_single_quotes_for_bash . "' 'Terminal_Window_Was_Opened_Automatically_by_ApolliaLib' '" . $ApolliaLib_Settings->script_ending_type . "' '" . $ApolliaLib_Settings->automaticness_setting . "' $all_argv_args";
	
	
	$escaped_command_line_without_self_repeat = Escape_Single_Quotes_for_Bash($command_line_without_self_repeat);
	
	$command_line_with_self_repeat = $command_line_without_self_repeat . "'$escaped_command_line_without_self_repeat'";
	
	
	#!!!!
	return ($command_line_without_self_repeat, $command_line_with_self_repeat);
		
}



############################################################################
#
#	Start of function 
#
#	Possibly_Open_New_Terminal_Window_and_Relaunch_Self()
#

sub Possibly_Open_New_Terminal_Window_and_Relaunch_Self
{

	
	#----
	my $should_proceed_in_launch_phase_1_as_though_we_are_now_in_launch_phase_2;
	my $First_Argv_Arg;	
	my $script_was_probably_double_clicked=false;

	my $relauncher_command_for_display;
	my $escaped_command_line_for_relauncher_command_for_display;
	
	my $command_line_without_self_repeat;
	my $command_line_with_self_repeat;
	
	#@@@@
	$should_proceed_in_launch_phase_1_as_though_we_are_now_in_launch_phase_2=false;
	$First_Argv_Arg=$ARGV[0];
	
	
	
	##############################
		
	if ( ! defined $First_Argv_Arg)
	{	
		# There will be no ARGV args if the script was run by double-clicking.
		#
		# It's also possible the script was launched with no args via a command line, 
		# but, we have no way of knowing the difference.
		
		$script_was_probably_double_clicked=true;
		
		# Only giving this a value so as to avoid an annoying little warning
		# about using an undefined variable:
		$First_Argv_Arg="Script_Was_Probably_Double_Clicked";
	}
	
	
	if ( $First_Argv_Arg eq "Terminal_Window_Was_Opened_Automatically_by_ApolliaLib" )
	{	
		$relauncher_command_for_display=pop(@ARGV);
			# This actually removes it from the real ARGV array, 
			# not merely a copy of the ARGV array.
			
		
		$escaped_command_line_for_relauncher_command_for_display=Escape_Single_Quotes_for_Bash($relauncher_command_for_display);
		
		$relauncher_command_for_display=$relauncher_command_for_display . " '$escaped_command_line_for_relauncher_command_for_display'";

	}
	
	
	if ( $First_Argv_Arg ne "Terminal_Window_Was_Opened_Automatically_by_ApolliaLib" )
	{	
		# Then, we need to build the command line that can relaunch the script in a new
		# window.  Even if we aren't actually going to run it, we might want to display it.
		
		($command_line_without_self_repeat, $command_line_with_self_repeat) = Build_Command_Line_That_Relaunches_Script_in_New_Terminal_Window();
		
		
		
		if ($ApolliaLib_Settings_say_we->should_launch_new_terminal_window && $First_Argv_Arg ne "Dont_Open_Window")
		{	
			print "\n\nNow attempting to relaunch this script inside a new terminal window...";
		}
		else
		{	print "\n\nNot relaunching in a new terminal window, but here's the command line that would have been executed if we were:";
			
		}
		
		print "\n\n\n# $command_line_with_self_repeat";
		print "\n\n";
		
		$relauncher_command_for_display=$command_line_with_self_repeat;
		
		if ($ApolliaLib_Settings_say_we->should_launch_new_terminal_window && $First_Argv_Arg ne "Dont_Open_Window")
		{
			
			
			print "\n\nSee the other terminal window for more!\n\n";
			
			
			#!!!!
			exec ($command_line_with_self_repeat);
			
			
			#!!!!
			die;
		}
		else
		{	
			$should_proceed_in_launch_phase_1_as_though_we_are_now_in_launch_phase_2=true;		
		}
		
	}
	
	
	
	if ( $First_Argv_Arg eq "Terminal_Window_Was_Opened_Automatically_by_ApolliaLib" || $First_Argv_Arg eq "Dont_Open_Window" || $should_proceed_in_launch_phase_1_as_though_we_are_now_in_launch_phase_2 )
	{	
		
		if ($ApolliaLib_Settings_say_we->should_print_arguments_given_to_script )
		{
			if (@ARGV)
			{	
				print "\n\nArguments given to this script:";
		
				Print_Array_Indentedly(\@ARGV);
			
				
				print "\n\nEnd of arguments given to this script.";
			}
			else
			{	print "\n\nNo arguments given to this script!";
				
			}			
		}
		if ( $ApolliaLib_Settings_say_we->should_print_relaunch_command_in_launch_phase_2 && !$should_proceed_in_launch_phase_1_as_though_we_are_now_in_launch_phase_2)
		{	

			
			print "\n\n\n\nCommand line for relaunching this script in a terminal window:\n\n	$relauncher_command_for_display";
		

		}
	}
}

#
#  End of function Possibly_Open_New_Terminal_Window_and_Relaunch_Self()
#
#          which relaunches the script inside a new terminal window.
#
#
############################################################################



sub Typical_Script_Launch
{	
	
	
	
	##############################
	
	Determine_Script_Ending_Type_Using_Argv();
	
	Determine_Automaticness_Using_Argv();
	
	if ( $ApolliaLib_Settings->terminal_window_title eq "Not Yet Specified")
	{	
		$ApolliaLib_Settings->Make_Terminal_Window_Title();
	}
	
	$Launched_Script_Details->Announce_Script_Now_Running();
	
	print "\n\n";
	
	$Launched_Script_Details->Announce_Datime_of_Launch();
	
	
	Abort_Script_Before_Terminal_Window_Launch_If_Appropriate();
	
	

	Possibly_Open_New_Terminal_Window_and_Relaunch_Self();
		
	Abort_Script_If_Appropriate();
	
	Remove_Now_Unneeded_Clutter_from_ARGV();
	
}



1;