# ApolliaLib :: Common :: Script_Details.pm
#
# Creates the $Launched_Script_Details object, which contains
# details about the script that was launched.  Also has related
# functions.


use strict;
use warnings;


package ApolliaLib::Common::Script_Details;



################################################################
#
#                         Exported Stuff
#
# This bit specifies which parts of this module are made available to
# scripts that use the following line:
#
# 	use ApolliaLib::Common::Script_Details;
#
#
# I pasted much of the below from:
#
# 	http://perldoc.perl.org/perlmod.html


BEGIN 
{
	require Exporter;

	#set the version for version checking
	our $VERSION = 1.00;

	#Inherit from Exporter to export functions and variables
	our @ISA = qw(Exporter);

	#Functions and variables which are exported by default
	our @EXPORT = qw(  
		$Launched_Script_Details 
		$Launched_Script
	
		);

	#Functions and variables which can be optionally exported
	our @EXPORT_OK = qw(
	
		);
}



#
#                End of Exported Stuff section. 
#
#
################################################################



##################################################
#
#	Needed imports from other modules
#

use ApolliaLib::Common::Path_String_Handling qw (
	Get_First_Named_Dir_in_Path
	Get_Second_Named_Dir_in_Path										
	Get_Filename__Parentdirs__and_File_Suffix
	);
	
	
	
use ApolliaLib::Common::Misc qw ( 
	true
	false
	Escape_Single_Quotes_for_Bash 

	Print_Hash_Indentedly
	);


use ApolliaLib::Common::Settings qw ( 
	$ApolliaLib_Settings
	$ApolliaLib_Settings_say_we
	);


use ApolliaLib::Common::Completed_Script (
	"Note_of_Successful_Completion_Exists_or_Not",
	"Get_Path_of_Note_of_Successful_Completion"
	);

	
#use Data::Dumper;

use Cwd qw (abs_path);

use File::stat;



use Object::Tiny qw( 
	full_unescaped_path 
	full_path_with_escaped_single_quotes_for_bash 

	unescaped_script_name_without_suffix
	full_unescaped_parentdirs
	file_suffix
	
	unescaped_script_name
	
	disk
	mountpoint_parentdir
	
	script_version
	script_ApolliaLib_version
	script_title
	privacy_level
	privacy_level_of_current_location
	script_description
	script_last_modification_datime
	was_successfully_completed_on_this_run
	datime_of_this_run
	datime_this_script_ended
	was_already_completed_before_this_run
	path_of_note_of_successful_completion
	);
	
	
#
#	End of Needed imports from other modules
#
##################################################




################################################################
#
#	Start of stuff unique to this module
#

sub new
{
	my $class = shift;
	
	
	#----
	my $self;
	
	#@@@@
	$self = {};
	

	
	##############################
		
	bless $self, $class;
	
	return $self;
}



sub Initialize 
{
	my $self = $_[0];
	
		
	#########################################################################
	#
	#   Default settings you can adjust if desired.  Just bear in mind it
	#	will affect every script that uses ApolliaLib!
	#
	
	my $privacy_level="Public";
										$self->{'privacy_level'} = $privacy_level;
	
		# Public|Private
	
	
	# 11:23:24 8/15/2014.  I assume the following might easily get overwritten by individual scripts' settings:
	
	my $script_version="Not Yet Specified";
									$self->{'script_version'} = $script_version;

	my $script_ApolliaLib_version="Not Yet Specified";
									$self->{'script_ApolliaLib_version'} = $script_ApolliaLib_version;
									
	my $script_title="Not Yet Specified";
										$self->{'script_title'} = $script_title;
	
	my $script_description="Not Yet Specified";
										$self->{'script_description'} = $script_description;
										
	#
	#   End of Default settings you can adjust if desired
	#
	#########################################################################
	
	
	
#########################################################################
#
#   Settings you shouldn't mess with, which are calculated or observed, 
#	or which are set later inside individual scripts.
#

		
	my $was_successfully_completed_on_this_run=false;
										$self->{'was_successfully_completed_on_this_run'} = $was_successfully_completed_on_this_run;
	
	
	my $full_unescaped_path=abs_path($0);
										$self->{'full_unescaped_path'} = $full_unescaped_path;
	

	my $was_already_completed_before_this_run=false;
										$self->{'was_already_completed_before_this_run'} = $was_already_completed_before_this_run;
				

	my $full_path_with_escaped_single_quotes_for_bash=Escape_Single_Quotes_for_Bash($full_unescaped_path);
										$self->{'full_path_with_escaped_single_quotes_for_bash'} = $full_path_with_escaped_single_quotes_for_bash;
										
	
	my $path_of_note_of_successful_completion=false;
										$self->{'path_of_note_of_successful_completion'} = $path_of_note_of_successful_completion;


							
	my $unescaped_script_name_without_suffix;
	my $full_unescaped_parentdirs;
	my $file_suffix;
	
	($unescaped_script_name_without_suffix,$full_unescaped_parentdirs,$file_suffix) =
		Get_Filename__Parentdirs__and_File_Suffix($full_unescaped_path);
										
										$self->{'unescaped_script_name_without_suffix'}=$unescaped_script_name_without_suffix;
										
										$self->{'full_unescaped_parentdirs'} = $full_unescaped_parentdirs;
										
										$self->{'file_suffix'}=$file_suffix;
						
	
	
	my $unescaped_script_name=$unescaped_script_name_without_suffix . $file_suffix;
										
										$self->{'unescaped_script_name'}=$unescaped_script_name;
	
	
	my $disk=Get_Second_Named_Dir_in_Path($full_unescaped_parentdirs);
										$self->{'disk'}=$disk;
	
	my $mountpoint_parentdir=Get_First_Named_Dir_in_Path($full_unescaped_parentdirs);
										$self->{'mountpoint_parentdir'}=$mountpoint_parentdir;

	
	my $script_last_modification_datime;
	my $stat = stat($full_unescaped_path);
	
	if (!$stat)
	{	$script_last_modification_datime="Couldn't Retrieve Modification Datime";
	}
	else
	{	$script_last_modification_datime=$stat->mtime;
	}
											$self->{'script_last_modification_datime'} = $script_last_modification_datime;

	#print "script_last_modification_datime: $script_last_modification_datime ";
	#my $printable;
	
	#$printable = localtime($script_last_modification_datime);
	#print "printable: $printable ";
	
	
	my $datime_of_this_run=time;
											$self->{'datime_of_this_run'}=$datime_of_this_run;
	

	my $datime_this_script_ended="Not Yet Ended";
											$self->{'datime_this_script_ended'}=$datime_this_script_ended;
											
	
	my $privacy_level_of_current_location;
	
		
	my $position_of_string__slash_truecrypt;
	$position_of_string__slash_truecrypt = index($full_unescaped_path, "/truecrypt");
	
	if ($position_of_string__slash_truecrypt == -1 )
	{	$privacy_level_of_current_location="Public";
		
	}
	else
	{	$privacy_level_of_current_location="Private";
	}
										$self->{'privacy_level_of_current_location'} = $privacy_level_of_current_location;

	
#
#   End of Settings you shouldn't mess with, which are calculated or observed, 
#	or which are set later inside individual scripts.
#
#########################################################################
	
	
	return $self;
}

#
#	End of Initialize() method
#	
#	of 
#	
#	$Launched_Script_Details
#
#
####################################################




############################################################################
#
#
# 	Boring setter functions
#
#



sub Description
{	# For setting the script description.

	my $self = $_[0];
	my $script_description=$_[1];


	##############################
	
	$self->{'script_description'} = $script_description;
	
}



sub Title
{	# For setting the script title.

	my $self = $_[0];
	my $script_title=$_[1];
	
	
	
	##############################
		
	$self->{'script_title'} = $script_title;
	
}



sub ApolliaLib_Version
{	# For setting the version of the ApolliaLib modules that was used when building or updating this script.

	my $self = $_[0];
	my $script_ApolliaLib_version=$_[1];


	
	##############################
		
	$self->{'script_ApolliaLib_version'} = $script_ApolliaLib_version;
	
}



sub Version
{	# For setting the script version.

	my $self = $_[0];
	my $script_version=$_[1];


	
	##############################
		
	$self->{'script_version'} = $script_version;
	
}



#-------------------------------------------------
#
#
# 	Boring setter functions related to privacy
#
#


sub is_Private()
{	# Sets script private.
	my $self = $_[0];
	


	##############################
	
	$self->Privacy("Private");
}



sub is_Public()
{	# Sets script public.
	my $self = $_[0];
	
	$self->Privacy("Public");
}



sub Privacy
{	# For setting the privacy level.

	my $self = $_[0];
	my $privacy_level=$_[1];
	
	
	#----
	
	my $lowercase_privacy_level;
	my $result;



	##############################		
		
	$lowercase_privacy_level=lc($privacy_level);
	
	if ($lowercase_privacy_level eq "public")
	{	$result="Public";
	}
	else
	{	$result="Private";
	}
	
	
	$self->{'privacy_level'} = $result;
	
}



#
#
# 	End of Boring setter functions related to privacy
#
#
#-------------------------------------------------



#-------------------------------------------------
#
#
# 	Boring setter functions related to script completion
#
#

sub Was_Successfully_Completed
{	# For making it known to ApolliaLib that this script was successfully completed.
	my $self = $_[0];
	


	##############################
	
	$self->{'was_successfully_completed_on_this_run'}=true;
}



sub Store_Path_of_Note_of_Successful_Completion
{	my $self=$_[0];


	
	##############################	
	
	$self->{'path_of_note_of_successful_completion'}=Get_Path_of_Note_of_Successful_Completion();
}


#
#
# 	End of Boring setter functions related to script completion
#
#
#-------------------------------------------------



#
#
# 	End of Boring setter functions
#
#
############################################################################




############################################################################
#
#
# 	Functions related to Script completion
#
#



sub Retrieve_Text_from_Completion_Note_File
{	my $self = $_[0];
	
	
	#----
	my $note_path;
	my @note_text;
	
	#@@@@		
	$note_path=$self->path_of_note_of_successful_completion;
	


	##############################	
	
	open (my $fh, "<$note_path");
	@note_text=<$fh>;
		
	close $fh;
	
	
	#!!!!
	return \@note_text;
	
}



sub Find_Out_If_This_Script_Was_Already_Completed_Before_This_Run
{	my $self=$_[0];


	##############################	
	
	$self->{'was_already_completed_before_this_run'}=Note_of_Successful_Completion_Exists_or_Not();
	
	
	#!!!!
	return $self->was_already_completed_before_this_run;
}



#
#
# 	End of Functions related to Script completion
#
#
############################################################################




############################################################################
#
#
# 	Display functions
#
#


sub Print_Script_Title_and_Path
{
	my $self=$_[0];
	
	
	#----
	my $text;
	


	##############################	
	
	$text = "\n\n";
	$text = $text . $self->script_title;
	$text = $text . "\n\n";
	$text = $text . $self->full_unescaped_path;
	
	print $text;

	
	#!!!!
	return $text;
}



sub Announce_Script_Now_Running
{	
	my $self=shift;


	
	##############################	
		
	print "\n\n\n\n*(*)*\n\n\n\nPerl Script Now Running:\n\n	";
	print $self->full_unescaped_path;
	
	$self->Announce_Title__Version__and_Description();
}



sub Announce_Datime_of_Launch
{	
	my $self=shift;
	

	#----
	my $printable_datime;



	##############################
	
	print "\n\nDatime of launch:	";
		
	$printable_datime=localtime( $self->datime_of_this_run );
	
	print $printable_datime;
	
	print "\n\n\n";
}



sub Announce_Title__Version__and_Description
{	
	my $self=shift;
	
	

	##############################	
	
	if ( $self->script_title ne "Not Yet Specified")
	{
		print "\n\n\n\nScript: ";
		print $self->script_title;
		
		if ($ApolliaLib_Settings_say_we->should_use_script_version_in_announcement_of_script_running)
		{
			print " - Version ";
			print $self->script_version;
		}
	}
	if ( $self->script_description ne "Not Yet Specified")
	{
		print "\n\n";
		print $self->script_description;
	}

}



#
#
# 	End of Display functions
#
#
############################################################################




#---------------------------------------------------------------------------
#
#	Now the $Launched_Script_Details object actually gets created, 
#	but no attributes are set yet.
#
#

our $Launched_Script_Details;

$Launched_Script_Details=ApolliaLib::Common::Script_Details->new();


#---------------------------------------------------------------------------
#
# 	Aliases, equivalent to $Launched_Script_Details
#
#

our $Launched_Script;

$Launched_Script=$Launched_Script_Details;



#---------------------------------------------------------------------------
#
#	Now, the $Launch_Script_Details object's attributes get set to their defaults.
#


$Launched_Script_Details->Initialize();



1;