# ApolliaLib :: File_or_Folder_Handling :: Diff_Comparison.pm
#
# Stuff related to comparing files/folder via the diff console command.


use strict;
use warnings;


package ApolliaLib::File_or_Folder_Handling::Diff_Comparison;



################################################################
#
#                         Exported Stuff
#
# This bit specifies which parts of this module are made available to
# scripts that use the following line:
#
# 	use ApolliaLib::File_or_Folder_Handling::Diff_Comparison;
#
#
# I pasted much of the below from:
#
# 	http://perldoc.perl.org/perlmod.html


BEGIN 
{
	require Exporter;

	#set the version for version checking
	our $VERSION = 1.00;

	#Inherit from Exporter to export functions and variables
	our @ISA = qw(Exporter);

	#Functions and variables which are exported by default
	our @EXPORT = qw(  
		Detailed_Compare_1st_and_2nd_Paths_with_Diff
		Compare_First_and_Second_Paths_with_Diff
		Note_First_Path_for_Diff
		Note_Second_Path_for_Diff
		
		);

	#Functions and variables which can be optionally exported
	our @EXPORT_OK = qw(
		
		);
}



#
#                End of Exported Stuff section. 
#
#
################################################################



##################################################
#
#	Needed imports from other modules
#

use ApolliaLib::Common::Misc qw (
	true
	false
	Escape_Single_Quotes_for_Bash
	Display_and_Do_Command_Line
	Display_and_Do_Command_Line_and_Result
	Print_Octal_Value_Properly
	);

use ApolliaLib::Common::End_Script (
	"End_Script_and_Wait_for_Return"

	);

use ApolliaLib::Common::Settings qw (
	$ApolliaLib_Settings
	);

use ApolliaLib::File_Handling::Overwriting::Single_File (
	"Overwrite_Filepath_with_Text"
	);
	
use ApolliaLib::File_Handling::Contents (
	"Make_String_out_of_File_Contents"
);

#
#	End of Needed imports from other modules
#
##################################################




################################################################
#
#	Start of stuff unique to this module
#


sub Detailed_Compare_1st_and_2nd_Paths_with_Diff
{

	#----
	my $diff_path_1;
	my $diff_path_2;
	
	my $escaped_diff_path_1;
	my $escaped_diff_path_2;
	
	my $fullpath_to_diff_note_1;
	my $fullpath_to_diff_note_2;
	
	my $command_line;
	my $result;
	
	#@@@
	$fullpath_to_diff_note_1=$ApolliaLib_Settings->fullpath_to_diff_note_1;
	$fullpath_to_diff_note_2=$ApolliaLib_Settings->fullpath_to_diff_note_2;
	
	
	
	##############################
	
	$diff_path_1=Make_String_out_of_File_Contents( $fullpath_to_diff_note_1 );

	$diff_path_2=Make_String_out_of_File_Contents( $fullpath_to_diff_note_2 );

	$escaped_diff_path_1=Escape_Single_Quotes_for_Bash($diff_path_1);
	$escaped_diff_path_2=Escape_Single_Quotes_for_Bash($diff_path_2);

	$command_line = "diff -r '$escaped_diff_path_1' '$escaped_diff_path_2'";


	print "\n\n# $command_line";

	print "\n\n";

	$result=`$command_line`;

	print "\n\n";

	print $result;
	
	
	#!!!!
	return $result;
}

sub Compare_First_and_Second_Paths_with_Diff
{

	#----
	my $diff_path_1;
	my $diff_path_2;
	
	my $escaped_diff_path_1;
	my $escaped_diff_path_2;
	
	my $fullpath_to_diff_note_1;
	my $fullpath_to_diff_note_2;
	
	my $command_line;
	my $result;
	
	#@@@
	$fullpath_to_diff_note_1=$ApolliaLib_Settings->fullpath_to_diff_note_1;
	$fullpath_to_diff_note_2=$ApolliaLib_Settings->fullpath_to_diff_note_2;
	
	
	
	##############################
	
	$diff_path_1=Make_String_out_of_File_Contents( $fullpath_to_diff_note_1 );

	$diff_path_2=Make_String_out_of_File_Contents( $fullpath_to_diff_note_2 );

	$escaped_diff_path_1=Escape_Single_Quotes_for_Bash($diff_path_1);
	$escaped_diff_path_2=Escape_Single_Quotes_for_Bash($diff_path_2);

	$command_line = "diff -qr '$escaped_diff_path_1' '$escaped_diff_path_2'";


	print "\n\n# $command_line";

	print "\n\n";

	$result=`$command_line`;

	print "\n\n";

	print $result;
	
	
	#!!!!
	return $result;
}



sub Note_First_Path_for_Diff
{	
	my $filepath=$_[0];
	
	
	#----
	my $fullpath_to_diff_note_1;
	
	#@@@
	$fullpath_to_diff_note_1=$ApolliaLib_Settings->fullpath_to_diff_note_1;

	
	
	##############################
	
	Overwrite_Filepath_with_Text( 
		$fullpath_to_diff_note_1, 
		
		"and put the following text:", 
		
		"$filepath"
	);	
}



sub Note_Second_Path_for_Diff
{	
	my $filepath=$_[0];
	
	
	#----
	my $fullpath_to_diff_note_2;
	
	#@@@
	$fullpath_to_diff_note_2=$ApolliaLib_Settings->fullpath_to_diff_note_2;
	
	
	
	##############################
	
	Overwrite_Filepath_with_Text( 
		$fullpath_to_diff_note_2, 
		
		"and put the following text:", 
		
		"$filepath"
	);	
}



1;