# ApolliaLib :: Folder_Handling :: Moving :: Single_Folder.pm
#
# Stuff related to single folders.  Moving.


use strict;
use warnings;


package ApolliaLib::Folder_Handling::Moving::Single_Folder;



################################################################
#
#                         Exported Stuff
#
# This bit specifies which parts of this module are made available to
# scripts that use the following line:
#
# 	use ApolliaLib::Folder_Handling::Moving::Single_Folder;
#
#
# I pasted much of the below from:
#
# 	http://perldoc.perl.org/perlmod.html


BEGIN 
{
	require Exporter;

	#set the version for version checking
	our $VERSION = 1.00;

	#Inherit from Exporter to export functions and variables
	our @ISA = qw(Exporter);

	#Functions and variables which are exported by default
	our @EXPORT = qw(  
		Move_Folder_to_Folder
		);

	#Functions and variables which can be optionally exported
	our @EXPORT_OK = qw(
	
		);
}



#
#                End of Exported Stuff section. 
#
#
################################################################



##################################################
#
#	Needed imports from other modules
#

use ApolliaLib::Common::Misc qw (
	true
	false
	Escape_Single_Quotes_for_Bash
	necho
	Display_and_Do_Command_Line_and_Result
	Add_Slash_If_Needed_To_
	);

use ApolliaLib::Common::End_Script qw (
	End_Script_and_Wait_for_Return
	);

use ApolliaLib::Common::Path_String_Handling qw (
	Get_Filename_from_Path
	
	);

#
#	End of Needed imports from other modules
#
##################################################




################################################################
#
#	Start of stuff unique to this module
#



sub Move_Folder_to_Folder
{
	my $folder_path_to_move=$_[0];
	my $destination_folder_path=$_[1];
	
	
	#----
	my $command_line;
	my $filename_of_folder_to_move;
	my $final_path_after_move;
	my $escaped_folder_path_to_move;
	my $escaped_destination_folder_path;
	
	#@@@@
	$filename_of_folder_to_move = Get_Filename_from_Path($folder_path_to_move);
	
	$escaped_folder_path_to_move = Escape_Single_Quotes_for_Bash($folder_path_to_move);
	$escaped_destination_folder_path = Escape_Single_Quotes_for_Bash($destination_folder_path);
	
	$final_path_after_move = Add_Slash_If_Needed_To_($destination_folder_path);
	$final_path_after_move = $final_path_after_move . $filename_of_folder_to_move;
	
	
	##############################
	
	if 	(	!-e $folder_path_to_move 
			|| 
			!-d $folder_path_to_move 
			|| 
			!-e $destination_folder_path 
			|| 
			!-d $destination_folder_path 
			||
			-e $final_path_after_move
		)
	{	print "\n\n\nCouldn't move folder:
	$folder_path_to_move";
	
		if ( !-e $folder_path_to_move)
		{
			print "\n\nNo folder exists at that path!";
			
		}
		elsif (!-d $folder_path_to_move)
		{	print "\n\nThat path actually leads to something other than a folder!";
		}
		
		if ( !-e $destination_folder_path)
		{
			print "\n\nNonexistent destination folder:
	$destination_folder_path";
			return false;
		}
		elsif ( !-d $destination_folder_path)
		{
			print "\n\nDestination path leads to something other than a folder:
	$destination_folder_path";
		}
		elsif (-e $final_path_after_move)
		{	print "\n\nSomething already exists at:
	$final_path_after_move";
		}
		return false;
	}
	
	print "Now attempting to move $folder_path_to_move to $destination_folder_path ...";
	
	$command_line="mv --no-clobber '$escaped_folder_path_to_move' '$escaped_destination_folder_path'";
	
	#necho $command_line;
	
	Display_and_Do_Command_Line_and_Result($command_line);
	
}



1;