#!/bin/sh

#	Script:                  Puppy Setup Kit Blueprint:               
#
#                  00-Script Needed By All Lupu5284 Blueprints.sh
#
#                    For Apollia's Lucid Puppy 5.2.8-4 Setup Kit
#
#
#	Version 1.0
#	by Apollia of Astroblahhh.Com.  http://astroblahhh.com/
#
#
#	Mostly completed May 16, 2014.
#
#	Polished a bit August 15 and August 25, 2014.
#
#
#
#------------------------------------------------------------------------------
#
# Not a standalone script - this is intended to be run via a "source" command
# inside a blueprint script like "Default for Bruno 2".  It sets some variables
# used by all Lucid Puppy 5.2.8 version 004 blueprint scripts, and also
# launches a script which installs the Perl module local::lib.
#
#------------------------------------------------------------------------------
#
#
#
# Under the GNU General Public License v3.0.
#
# Copyright (C) 2014  Apollia
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
# Contact info:     http://astroblahhh.com/contact-apollia.shtml
#
# ----



echo
echo
echo "Now running 00-Script Needed By All Lupu5284 Blueprints.sh..."
echo

parentdirs_of_puppy_setup_kit=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Parentdirs of Puppy Setup Kit.txt")

setup_kit_folder_name=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Abbrev of Puppy Distro.txt")

setup_kit_mountpoint_parentdir=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Mountpoint Parentdir of Puppy Setup Kit.txt")

setup_kit_disk=$(cat "/root/zzzzz-tmp/Apollia's Puppy Setup Kit Settings/Main Disk of Puppy Setup Kit.txt")




###################################
#
# Later on, the below relative paths will be prefixed with the
# $full_path_to_blueprint_scripts.
#
#
# The resultant path (not what you should input below) will probably look something like:
#
# /[mountpoint parentdir of the disk this script is on]/[disk this script is on]/[parentdirs of the Puppy Setup Kits]/Woodland/Lupu5284/Apollia's Puppy Setup Kit/Blueprints/For All Blueprints/Install Perl module local-lib.sh"
#
#
# Don't begin paths with a slash.
#
# Also, don't try to put the first parenthesis on the line after the equal sign.
# Bash gets confused if you do that.


relative_paths_to_bash_setup_scripts_for_this_blueprint=(
	#"Bash/Install Perl.sh"
	"Install Perl module local-lib.sh"
	
)


relative_paths_to_perl_setup_scripts_for_this_blueprint=(
#	"Step 1 - Setup for Setup Kit, etc.pl" 
	
)



full_path_to_blueprint_scripts="/$setup_kit_mountpoint_parentdir/$setup_kit_disk/$parentdirs_of_puppy_setup_kit/Woodland/$setup_kit_folder_name/Apollia's Puppy Setup Kit/Blueprints/For All Blueprints"




if [ "$1" != "Terminal_Window_Was_Opened_Automatically" ]
then
	echo "Blueprint script hasn't relaunched itself in a terminal window yet - so, now returning from 00-Script Needed By All Lupu5284 Blueprints.sh."
	echo
	echo
	
	return
fi



##########################################################
#
#	Now, we run the Bash scripts that any Puppy setup can use,
#	such as the Bash script to install my Perl modules
#	(and some other Perl modules, not by me).

#should_install_without_asking="true"

Run_Array_of_Scripts()
{	
	# 1st argument: The shell command to use to run each script.
	#
	#	Examples: "perl" or "sh"
	#
	#
	# 2nd argument: A string to use as a prefix for each script's relative path.
	#
	#	Example: $full_path_to_setup_kit_scripts_for_any_puppy, which
	#	probably equates to something like:
	#
	#	/[mountpoint parentdir of the disk this script is on]/[disk this script is on]/Meadow/Woodland/Any
	#
	#
	# 3rd argument: An array of relative paths to scripts.
	#
	#	Example: relative_paths_to_bash_setup_scripts_for_this_blueprint[@]
	

	local script_executor="$1"
	local prefix_for_path_fragment="$2"
	declare -a array=("${!3}")

	# This page was helpful:
	#
	# http://stackoverflow.com/questions/1063347/passing-arrays-as-parameters-in-bash

	####
	
	local count_of_array_items
	
	count_of_array_items=${#array[@]}
	
	
	if [ $count_of_array_items -gt 0 ]
	then
		echo -e -n "\n\n\n\nRunning "
		echo -n "${script_executor^}"
		echo -n " scripts:"
		
		for path_fragment in "${array[@]}"
		do
			command_line=""
			echo -e "\n\n\n	$path_fragment"
			
			
			full_path_to_script_to_run="$prefix_for_path_fragment/$path_fragment"
			
		
			escaped_enclosed_full_path_to_script_to_run=$(Escape_Single_Quotes_for_Bash_and_Enclose_in_Single_Quotes "$full_path_to_script_to_run")
			
			command_line="$script_executor $escaped_enclosed_full_path_to_script_to_run 'Dont_Open_Window' 'Dont_Wait_For_Return_At_Scripts_End' 'Do_Things_Automatically'"
			
			
			if [ "$should_install_without_asking" == "true" ]
			then
					command_line="$command_line 'Install_Without_Asking'"
			fi
			


			echo -e "\n\n# command line $command_line\n\n"

			eval "$command_line"
		done
		
	fi
}



##########################################################
#
#	If the user specified any additional Bash scripts to run,
#	we loop through the list of them and run them.
#


Run_Array_of_Scripts "sh" "$full_path_to_blueprint_scripts" relative_paths_to_bash_setup_scripts_for_this_blueprint[@]





##########################################################
#
#	Now, we can start running Puppy Setup Kit scripts
#	written in Perl, which will all be fully able to use
#	the Perl modules just installed.
#

#Run_Array_of_Scripts "perl" "$full_path_to_blueprint_scripts" relative_paths_to_perl_setup_scripts_for_this_blueprint[@]



return



#
#
#  End of script.
#
############################