#!/usr/bin/perl

# Script:
# Step 1 - Setup for Setup Kit, etc - Lupu5284 Puppy Setup Kit


use strict;
use warnings;
use local::lib '/root/zzzzz-tmp/Apollias_Perl_Modules';



use ApolliaLib::Common::Loader;


$Launched_Script->Title("Step 1 - Setup for Lupu5284 Puppy Setup Kit, etc.");

$Launched_Script->Version("1");
$Launched_Script->ApolliaLib_Version("1");

$Launched_Script->Description("Puts a few necessary things in /root/zzzzz-tmp/, launches scripts to install the shell commands petgetjet and setkeycodes, and makes it so scripts using the legacy Lib-Apollia will still work. Also installs IceWM so when the keycodes are set in Step 2, the settings won't get overwritten by IceWM being installed after that.");


#$ApolliaLib->Shouldnt_Launch_New_Terminal_Window();		# Useful for debugging.

$ApolliaLib->Should_Note_Successful_Script_Completion();
$ApolliaLib->If_Script_Has_Been_Successfully_Completed_Before__Warn_and_Ask_if_User_Wants_to_Continue();
#$ApolliaLib->Dont_Rerun_If_Script_Has_Been_Successfully_Completed_Before();



use ApolliaLib::Puppy_Setup_Kit::Loader;


$Puppy_Setup_Kit->Puppy_Distro_is_("Lupu5284");


Typical_Script_Launch();

Typical_Postlaunch_Phase_for_Puppy_Setup_Kit_Script();


#####################################################
#
#	Start of most stuff unique to this script
#


#####################################
#
#	Additional modules
#
#

use ApolliaLib::Folder_Handling::Many_Folders ( 
	"Make_Many_Folder_Paths"
	);

#
#
#	End of additional modules
#
#####################################################



#####################################
#
#	Start of variable declarations
#

my @dirs_to_make;

my @scripts_to_launch__their_relative_paths;

my $should_proceed;

my $grandparentdirs_for_Main_Disk_of_Puppy_Setup_Kit_note_files;

my $Puppy_Puppy_Distro_Abbrev;

#
#
#	End of variable declarations
#
#####################################################


$Puppy_Puppy_Distro_Abbrev = $Puppy_Setup_Kit->Puppy_Distro_Abbrev();


$should_proceed
	= Ask_or_Dont_Ask_Whether_To_Do_Action
	(
		$Puppy_Setup_Kit->should_or_should_not_install_without_asking, 
		
		"proceed with Step 1 - Setup for $Puppy_Puppy_Distro_Abbrev Puppy Setup Kit, etc."
	);


if ( $should_proceed )
{

	#---------------------
	#
	# Scripts to launch:
	
	
	@scripts_to_launch__their_relative_paths = (

		# Needed so the Install_Pet() function works right:	
		"Lupu5284/Shell Commands/Install Shell Command - petgetjet.pl",


		# The default setkeycodes shell command in Puppy is a crippled Busybox version
		# which can't set keycodes above 128, so we replace it with a full version.
		
		"Lupu5284/Shell Commands/Install Shell Command - setkeycodes from non-Puppy full Ubuntu.pl",

		
		# Another crippled Busybox command is "addgroup", which can't actually be
		# used to add a user to a group.  So, here we install "usermod" from a
		# non-Puppy full Ubuntu Lucid.  18:16 09/05/2014. Unfortunately, it doesn't
		# seem fully-functional in Puppy either.  18:19 09/05/2014.  Maybe it's
		# because the ISO might be a later version of Ubuntu Lucid than is
		# actually used in Lupu5284:  ubuntu-10.04.4-desktop-i386.iso
		
		"Lupu5284/Shell Commands/Install Shell Command - usermod from non-Puppy full Ubuntu.pl",
		
		
		# By default in Lupu5284, it's way too easy to accidentally restart X Windows, 
		# or turn off or reboot your entire computer.  These fix that:
		
		"Lupu5284/Shell Commands/Install Safer Commands/Branching Script - Install Safer Shell Commands.pl",
		"Lupu5284/Shell Commands/Move Dangerous Commands/Branching Script - Move Dangerous Shell Commands.pl",
		
		
		# Breredon Meadow panel.  
		#
		# If you're using the Default for Bruno 2 blueprint,
		# the Play/Pause button on the Compaq SK-2800C keyboard will open it, once 
		# keycodes are set and Openbox settings installed.
		
		"Lupu5284/zzz-Breredon/Copy zzz-Breredon folder to root.pl",
		
		"Lupu5284/zzz-Breredon/Use zzz-Breredon as zzz-Meadow.pl",
	
		

		# Openbox
		"Lupu5284/Window Managers/Openbox/Settings Install - Openbox Lupu5284 Setup Kit defaults.pl",
		
		# Fbpanel
		"Lupu5284/Desktop Panels/Fbpanel/Settings Install - Fbpanel Lupu5284 Setup Kit defaults.pl",
		
		
		# TrueCrypt.  Displays annoying buttons to click that I don't know how to get rid of
		# automatically, so, I like to get it out of the way quickly.
		
		#"Any_32_bit_Pup/Non-Libre Stuff/TrueCrypt/Install TrueCrypt v7.1 for 32-bit Linuxes.pl",
		# The default TrueCrypt settings are installed in Step 5 - More Setup for [whatever computer].
		
				
		# IceWM.  Don't know why, but installing IceWM makes the nicer Openbox dark theme
		# suddenly appear.
		"Lupu5284/Window Managers/IceWM/Install Pet - IceWM window manager v1.3.7-pre2-L519-lucid--xdialog-removed-by-apollia.pl",
		
			# My default theme for IceWM
		"Any_Pup/Window Managers/IceWM/IceWM Theme Install - Velvet-Azul-ApMod-Mar-12-2011.pl",

			# My default IceWM settings
		"Lupu5284/Window Managers/IceWM/Settings Install - Most IceWM Default Settings.pl",
		
		
		# Icon collection
		"Any_Pup/Icons/Install Icons - Main Collection.pl",
		
		# GTK Theme Switch
		"Lupu5284/GTK Themes/Install Pet - GTK Theme Switch.pl",
		
		# Now switching to Crux GTK theme
		"Lupu5284/GTK Themes/Switch GTK Theme to Crux.pl",
	
		
		"Multiple_Pups/File Managers/Typical/Rox-Filer/Branching Script - Do Cosmetic Rox-Filer Setup.pl",
	
		"Lupu5284/Wallpaper/Make Symlink - More Wallpaper symlink pointing at Wallpaper folder on setup kit disk.pl",
	
	);
	
	
	Launch_Many_Relativepath_Scripts("perl", $Puppy_Setup_Kit->Realm_Path_Without_Pup("Woodland"), \@scripts_to_launch__their_relative_paths, "Dont_Open_Window", "Dont_Wait_For_Return_At_Scripts_End", "Do_Things_Automatically" );
	
	
	
	#---------------
	#
	# Dirs to make:

	#$grandparentdirs_for_Main_Disk_of_Puppy_Setup_Kit_note_files=$Puppy_Setup_Kit->grandparentdirs_for_Main_Disk_of_Puppy_Setup_Kit_note_files;
	
	#@dirs_to_make=(
	#	"$grandparentdirs_for_Main_Disk_of_Puppy_Setup_Kit_note_files$Puppy_Puppy_Distro_Abbrev",
		
	#	);
		
	#Make_Many_Folder_Paths( \@dirs_to_make );
	
	#---------------------
	#
	# Files to output.
	# 
	# These two lines aren't needed anymore because the Bash launch scripts
	# make these files.  But, if you'd rather do that with Perl, 
	# the option is available.
	
	
	#$Puppy_Setup_Kit->Output_Text_File_Stating_Main_Disk_of_Puppy_Setup_Kit();
		# It is assumed that whatever disk this Step 1 file is on is the main
		# disk of this Puppy Setup Kit.  
		#
		# The Main_Disk_of_Puppy_Setup_Kit attribute of the $Puppy_Setup_Kit  object
		# is used by files on other disks which may wish to launch scripts or 
		# do other things with files on the main setup kit disk.
	
	#$Puppy_Setup_Kit->Output_Text_File_Stating_Mountpoint_Parentdir_of_Puppy_Setup_Kit();
		# /mnt/ if using Lupu5284, or /media/ if using LH64_602_B2.
	
	#------
	#
	# And temporary legacy stuff for old scripts that still need it.
	
	$Puppy_Setup_Kit->Output_Text_File_Stating_Fullpath_to_Legacy_Lib_Apollia();
	$Puppy_Setup_Kit->Output_Text_File_Stating_Disk_of_Legacy_Lib_Apollia();
	
	
	
	$Launched_Script->Was_Successfully_Completed();
	
}


End_Script();